@@ -1,10 +1,12 @@
 # coding=utf8
 
+import re
 import time
 import random
 import warnings
 
 from hashlib import md5
+from vk.utils import make_handy
 
 try:
     from urlparse import urlparse, parse_qsl  # Python 2
@@ -35,7 +37,7 @@ def json_iter_parse(response_text):
 
 class APISession(object):
     def __init__(self, app_id, user_email=None, user_password=None, access_token=None, app_secret=None,
-                 scope='friends,photos,audio,video,wall', timeout=1):
+                 scope='friends,photos,audio,video', timeout=1, api_version='5.20'):
 
         if (not user_email or not user_password) and not access_token and not app_secret:
             raise ValueError('Arguments user_email and user_password, or token, or app_secret are required')
@@ -48,6 +50,8 @@ class APISession(object):
 
         self.access_token = access_token
         self.scope = scope or ''
+        
+        self.api_version = api_version
 
         self._timeout = timeout
 
@@ -84,6 +88,25 @@ class APISession(object):
             'display': 'mobile',
         }
         response = session.post('https://oauth.vk.com/authorize', oauth_data)
+
+        if u'login.vk.com/?act=grant_access' in response.text:
+            pattern = u'<form method="post" action="(?P<url>[^"]+)">'
+            match = re.search(pattern, response.content)
+            match_dict = match.groupdict()
+            if 'url' in match_dict:
+                response = session.get(match_dict['url'])
+            else:
+                try:
+                    json_data = response.json()
+                except ValueError:  # not json in response
+                    error_message = 'OAuth2 grant access error'
+                else:
+                    error_message = 'VK error: [{0}] {1}'.format(
+                        json_data['error'],
+                        json_data['error_description']
+                    )
+                raise VkAuthorizationError(error_message)
+
         parsed_url = urlparse(response.url)
         token_dict = dict(parse_qsl(parsed_url.fragment))
         if 'access_token' in token_dict:
@@ -110,6 +133,7 @@ class APISession(object):
                 for error in errors:
                     warnings.warn(str(error))
 
+                # return make_handy(data['response'])
                 return data['response']
 
         raise VkAPIError(errors[0])
@@ -120,7 +144,8 @@ class APISession(object):
             params = {
                 'access_token': self.access_token,
                 'timestamp': int(time.time()),
-                }
+                'v': self.api_version,
+            }
             params.update(kwargs)
             url = 'https://api.vk.com/method/' + method
         else:
@@ -128,13 +153,13 @@ class APISession(object):
                 'api_id': str(self.app_id),
                 'method': method,
                 'format': 'JSON',
-                'v': '5.0',
+                'v': self.api_version,
                 'random': random.randint(0, 2 ** 30),
                 'timestamp': int(time.time()),
             }
             params.update(kwargs)
             params['sig'] = self._signature(params)
-            url = 'http://api.vk.com/api.php'
+            url = 'https://api.vk.com/api.php'
 
         return self.session.post(url, params, timeout=timeout or self._timeout)
 
