@@ -6,6 +6,7 @@ import time
 
 import unittest
 import vk
+from vk.utils import HandyList, make_handy, HandyDict
 
 sys.path.append(os.path.join(os.path.dirname(__file__), '..'))
 
@@ -19,11 +20,11 @@ USER_PASSWORD = ''
 import test_props
 
 
-
 class VkTestCase(unittest.TestCase):
 
     def setUp(self):
         self.vk_token_api = vk.API(test_props.APP_ID, test_props.USER_EMAIL, test_props.USER_PASSWORD)
+        self.vk_token_api.api_version = u'5.20'
         self.vk_secret_api = vk.API(test_props.APP_ID, app_secret=test_props.APP_SECRET)
 
 
@@ -41,7 +42,10 @@ class VkTestCase(unittest.TestCase):
 
 
     def test_get_profiles_via_token(self):
-        self.assertEqual(self.get_first_profile(self.vk_token_api), u'Дуров')
+        profiles = self.vk_token_api.users.get(user_id=1)
+
+        print(profiles)
+        self.assertEqual(profiles.first.last_name, u'Дуров')
 
     def test_get_profiles_via_secret(self):
         self.assertRaises(vk.VkAPIError, lambda: self.get_first_profile(self.vk_secret_api))
@@ -51,5 +55,19 @@ class VkTestCase(unittest.TestCase):
         return profiles[0]['last_name']
 
 
+class HandyContainersTestCase(unittest.TestCase):
+
+    def test_list(self):
+        handy_list = make_handy([1, 2, 3])
+        self.assertIsInstance(handy_list, HandyList)
+        self.assertEqual(handy_list.first, 1)
+
+
+    def test_handy_dict(self):
+        handy_dict = make_handy({'key1': 'val1', 'key2': 'val2'})
+        self.assertIsInstance(handy_dict, HandyDict)
+        self.assertEqual(handy_dict.key1, 'val1')
+
+
 if __name__ == '__main__':
     unittest.main()
